@@ -991,6 +991,13 @@ class VariableOsInstallSplashSet(Variable):
     type = "bool"
     value = "on"
 
+class VariableClInstallFs(Variable):
+    """
+    Preferred fs
+    """
+    type = "list"
+
+    value = ["btrfs", "ext4", "reiserfs", "ext3"]
 
 class FlashUncompatible(VariableInterface):
     def uncompatible(self):
